"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputSourceExtractor = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const the_promise_1 = require("the-promise");
const original_source_1 = require("../input/original-source");
class InputSourceExtractor {
    constructor(logger) {
        this._originalSources = {};
        this._logger = logger.sublogger('InputSourcesExtractor');
    }
    get sources() {
        return the_lodash_1.default.flatten(this.originalSources.map(x => x.sources));
    }
    get originalSources() {
        return the_lodash_1.default.values(this._originalSources);
    }
    addMany(fileOrPatternOrUrls) {
        for (const x of fileOrPatternOrUrls) {
            this.addSingle(x);
        }
    }
    addSingle(fileOrPatternOrUrl) {
        this._logger.info('[addSingle] %s', fileOrPatternOrUrl);
        const key = fileOrPatternOrUrl;
        if (this._originalSources[key]) {
            return;
        }
        const orignalSource = new original_source_1.OriginalSource(fileOrPatternOrUrl);
        this._originalSources[key] = orignalSource;
    }
    extractSources() {
        return __awaiter(this, void 0, void 0, function* () {
            yield the_promise_1.Promise.serial(this.originalSources, (x) => the_promise_1.Promise.resolve(x.extractInputSources()));
        });
    }
    reconcile() {
        this._logger.info('[reconcile] BEGIN');
        this.debugOutput();
        for (const originalSource of this.originalSources) {
            originalSource.reconcile();
        }
        this._logger.info('[reconcile] END');
        this.debugOutput();
    }
    debugOutput() {
        this._logger.info('[InputSourceExtractor] BEGIN');
        for (const originalSource of this.originalSources) {
            originalSource.debugOutput();
        }
        this._logger.info('[InputSourceExtractor] END');
    }
}
exports.InputSourceExtractor = InputSourceExtractor;
//# sourceMappingURL=input-source-extractor.js.map